# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.security.v4.report.Severity import Severity  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.report.Stig import Stig  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.report.StigStatus import StigStatus  # noqa: F401,E501

class StigProjection(Stig):

    """

    :param title: (:attr:`title`) Title of the STIG control.
    :type title: 
     max=199 chars
    
    :param rule_id: (:attr:`rule_id`) Rule ID of the STIG control.
    :type rule_id: 
    
    
    :param stig_version: (:attr:`stig_version`) STIG ID of the control.
    :type stig_version: 
    
    
    :param identifiers: (:attr:`identifiers`) Additional identifiers used to describe this control.
    :type identifiers: 
    
    
    :param affected_clusters: (:attr:`affected_clusters`) List of clusters that failed the STIG control.
    :type affected_clusters: 
    
    
    :param severity: (:attr:`severity`) 
    :type severity: 
    
    
    :param status: (:attr:`status`) 
    :type status: 
    
    
    :param comments: (:attr:`comments`) The comments to explain why a STIG rule applies or does not apply to the cluster.
    :type comments: 
     max=499 chars
    
    :param fix_text: (:attr:`fix_text`) The command/steps to fix the STIG rule failure.
    :type fix_text: 
     max=499 chars
    
    :param benchmark_id: (:attr:`benchmark_id`) Benchmark ID of the STIG rules.
    :type benchmark_id: 
    
    
    :param ext_id: (:attr:`ext_id`) A globally unique identifier of an instance that is suitable for external consumption. 
    :type ext_id: 
    
    
    :param links: (:attr:`links`) A HATEOAS style link for the response.  Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource. 
    :type links: 
    
    
    :param tenant_id: (:attr:`tenant_id`) A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this ID to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server). 
    :type tenant_id: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'title': 'str',
        'rule_id': 'str',
        'stig_version': 'str',
        'identifiers': 'list[str]',
        'affected_clusters': 'list[str]',
        'severity': 'security.v4.report.Severity',
        'status': 'security.v4.report.StigStatus',
        'comments': 'str',
        'fix_text': 'str',
        'benchmark_id': 'str',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'title': 'title',
        'rule_id': 'ruleId',
        'stig_version': 'stigVersion',
        'identifiers': 'identifiers',
        'affected_clusters': 'affectedClusters',
        'severity': 'severity',
        'status': 'status',
        'comments': 'comments',
        'fix_text': 'fixText',
        'benchmark_id': 'benchmarkId',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, title=None, rule_id=None, stig_version=None, identifiers=None, affected_clusters=None, severity=None, status=None, comments=None, fix_text=None, benchmark_id=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        Stig.__init__(self, title, rule_id, stig_version, identifiers, affected_clusters, severity, status, comments, fix_text, benchmark_id, ext_id, links, tenant_id, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'security.v4.report.StigProjection'

    def _initialize_object_version(self):
        return 'v4.r0'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(StigProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StigProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

