# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.security.v4.common.ClusterProjection import ClusterProjection  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.config.ScheduleType import ScheduleType  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.config.SecurityConfig import SecurityConfig  # noqa: F401,E501

class SecurityConfigProjection(SecurityConfig):

    """

    :param cluster_projection: (:attr:`cluster_projection`) 
    :type cluster_projection: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'cluster_projection': 'security.v4.common.ClusterProjection',
        'cluster_ext_id': 'str',
        'is_high_strength_password_enabled': 'bool',
        'is_aide_enabled': 'bool',
        'is_secure_boot_enabled': 'bool',
        'is_cluster_lockdown_enabled': 'bool',
        'is_log_forwarding_enabled': 'bool',
        'cluster_scma_schedule': 'security.v4.config.ScheduleType',
        'ahv_scma_schedule': 'security.v4.config.ScheduleType',
        'is_ahv_defense_consent_banner_enabled': 'bool',
        'is_cluster_defense_consent_banner_enabled': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'cluster_projection': 'clusterProjection',
        'cluster_ext_id': 'clusterExtId',
        'is_high_strength_password_enabled': 'isHighStrengthPasswordEnabled',
        'is_aide_enabled': 'isAideEnabled',
        'is_secure_boot_enabled': 'isSecureBootEnabled',
        'is_cluster_lockdown_enabled': 'isClusterLockdownEnabled',
        'is_log_forwarding_enabled': 'isLogForwardingEnabled',
        'cluster_scma_schedule': 'clusterScmaSchedule',
        'ahv_scma_schedule': 'ahvScmaSchedule',
        'is_ahv_defense_consent_banner_enabled': 'isAhvDefenseConsentBannerEnabled',
        'is_cluster_defense_consent_banner_enabled': 'isClusterDefenseConsentBannerEnabled',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, cluster_projection=None, cluster_ext_id=None, is_high_strength_password_enabled=False, is_aide_enabled=False, is_secure_boot_enabled=False, is_cluster_lockdown_enabled=False, is_log_forwarding_enabled=False, cluster_scma_schedule=None, ahv_scma_schedule=None, is_ahv_defense_consent_banner_enabled=False, is_cluster_defense_consent_banner_enabled=False, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        SecurityConfig.__init__(self, cluster_ext_id, is_high_strength_password_enabled, is_aide_enabled, is_secure_boot_enabled, is_cluster_lockdown_enabled, is_log_forwarding_enabled, cluster_scma_schedule, ahv_scma_schedule, is_ahv_defense_consent_banner_enabled, is_cluster_defense_consent_banner_enabled, ext_id, links, tenant_id, *args, **kwargs)
        self.__cluster_projection = None
        self.discriminator = None
        if cluster_projection is not None:
            self.__cluster_projection = cluster_projection

    def _initialize_object_type(self):
        return 'security.v4.config.SecurityConfigProjection'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def cluster_projection(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.common.ClusterProjection`
        """  # noqa: E501
        return self.__cluster_projection

    @cluster_projection.setter
    def cluster_projection(self, cluster_projection):

        self.__cluster_projection = cluster_projection

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SecurityConfigProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityConfigProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

